==> content_insights_report-1.0.7.tar.gz: content_insights_report/tests/src/Functional/ContentInsightsReportTest.php <==
<?php

declare(strict_types=1);

namespace Drupal\Tests\content_insights_report\Functional;

use Drupal\Core\Url;
use Drupal\node\Entity\Node;
use Drupal\node\Entity\NodeType;
use Drupal\Tests\BrowserTestBase;
use Drupal\Tests\content_moderation\Traits\ContentModerationTestTrait;
use Drupal\workflows\Entity\Workflow;

/**
 * Tests the Content Insights report generation functionality.
 *
 * @group content_insights_report
 */
class ContentInsightsReportTest extends BrowserTestBase {

  use ContentModerationTestTrait;

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'node',
    'content_insights_report',
    'content_moderation',
    'workflows',
    'system',
    'user',
  ];

  /**
   * {@inheritdoc}
   */
  protected $profile = 'minimal';

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * A user with admin permissions.
   *
   * @var \Drupal\user\UserInterface[]
   */
  protected $reportViewer;

  /**
   * {@inheritdoc}
   */
  public function setUp(): void {
    parent::setUp();

    // Create a user with permission to access the report.
    $this->reportViewer = $this->drupalCreateUser([
      'administer content_insights_report settings',
      'view content_insights_report report',
      'administer nodes',
    ]);

    // Enable Content Moderation & Workflow module if not already enabled.
    $this->container
      ->get('module_installer')
      ->install([
        'node',
        'workflows',
        'content_moderation',
        'content_insights_report',
      ]);

    // Create a content type (if not already created).
    \Drupal::entityTypeManager()
      ->getStorage('node_type')
      ->load('article') ?: NodeType::create([
        'type' => 'article',
        'name' => 'Article',
      ])->save();

    // Create and assign a content moderation workflow.
    $workflow = Workflow::create([
      'id' => 'editorial',
      'label' => 'Editorial workflow',
      'type' => 'content_moderation',
    ]);
    $workflow->getTypePlugin()->addEntityTypeAndBundle('node', 'article');
    $workflow->save();

    // Create a node with "Draft" moderation state.
    $node = Node::create([
      'type' => 'article',
      'title' => 'Test Article',
      'body' => 'Test body content.',
    ]);
    // Set the moderation state to draft.
    $node->set('moderation_state', 'draft');
    $node->save();
  }

  /**
   * Test the Content Insights report page.
   */
  public function testReportPage(): void {
    // Log in as the test user.
    $this->drupalLogin($this->reportViewer);

    // Check the URL for the report page.
    $url = Url::fromRoute('content_insights_report.report');
    $this->drupalGet($url);

    // Assert that the report page loads.
    $this->assertSession()->statusCodeEquals(200);

    // Assert specific content is displayed on the page.
    // Test div id and not name of report can be changed.
    $this->assertSession()->responseContains('<div id="content_insights">');
  }

  /**
   * Test the behavior of the report when configurations are changed.
   */
  public function testReportWithConfigShowSummary(): void {
    // Simulate changing the configuration for content insights.
    // This can be done by either setting configuration
    // via config factory, or by using UI.
    \Drupal::configFactory()->getEditable('content_insights_report.settings')
      ->set('show_summary', 'yes')
      ->save();

    // Log in as the user.
    $this->drupalLogin($this->reportViewer);

    // Visit the report page after configuration change.
    $url = Url::fromRoute('content_insights_report.report');
    $this->drupalGet($url);

    // Assert that the report is reflecting the configuration change.
    // Test div id and not name of report can be changed.
    $this->assertSession()->responseContains('<div id="content_summary_report">');
  }

  /**
   * Test the behavior of the report when configurations are changed.
   */
  public function testReportWithConfigNotShowSummary(): void {

    // Simulate changing the configuration for content insights.
    // This can be done by either setting configuration
    // via config factory, or by using UI.
    \Drupal::configFactory()->getEditable('content_insights_report.settings')
      ->set('show_summary', 'no')
      ->save();

    // Log in as the user.
    $this->drupalLogin($this->reportViewer);

    // Visit the report page after configuration change.
    $url = Url::fromRoute('content_insights_report.report');
    $this->drupalGet($url);

    // Assert that the report is reflecting the configuration change.
    // Test div id and not name of report can be changed.
    $this->assertSession()->responseNotContains('<div id="content_summary_report">');
  }

  /**
   * Test the behavior of the report when configurations are changed.
   */
  public function testReportWithConfigShowContentInsightsReport(): void {

    // Simulate changing the configuration for content insights.
    // This can be done by either setting configuration
    // via config factory, or by using UI.
    \Drupal::configFactory()->getEditable('content_insights_report.settings')
      ->set('show_insights_report', 'yes')
      ->save();

    // Log in as the user.
    $this->drupalLogin($this->reportViewer);

    // Visit the report page after configuration change.
    $url = Url::fromRoute('content_insights_report.report');
    $this->drupalGet($url);

    // Assert that the report is reflecting the configuration change.
    // Test div id and not name of report can be changed.
    $this->assertSession()->responseContains('<div id="content_insights_report">');
  }

  /**
   * Test the behavior of the report when configurations are changed.
   */
  public function testReportWithConfigNotShowContentInsightsReport(): void {

    // Simulate changing the configuration for content insights.
    // This can be done by either setting configuration
    // via config factory, or by using UI.
    \Drupal::configFactory()->getEditable('content_insights_report.settings')
      ->set('show_insights_report', 'no')
      ->save();

    // Log in as the user.
    $this->drupalLogin($this->reportViewer);

    // Visit the report page after configuration change.
    $url = Url::fromRoute('content_insights_report.report');
    $this->drupalGet($url);

    // Assert that the report is reflecting the configuration change.
    // Test div id and not name of report can be changed.
    $this->assertSession()->responseNotContains('<div id="content_insights_report">');
  }

  /**
   * Test the behavior of the report when configurations are changed.
   */
  public function testReportWithConfigShowWorkflowModerationStateReport(): void {

    // Simulate changing the configuration for content insights.
    // This can be done by either setting configuration
    // via config factory, or by using UI.
    \Drupal::configFactory()->getEditable('content_insights_report.settings')
      ->set('show_workflow_moderation_state_report', 'yes')
      ->set('show_empty_results', 'yes')
      ->save();

    // Log in as the user.
    $this->drupalLogin($this->reportViewer);

    // Visit the report page after configuration change.
    $url = Url::fromRoute('content_insights_report.report');
    $this->drupalGet($url);

    // Assert that the report is reflecting the configuration change.
    // Test div id and not name of report can be changed.
    $this->assertSession()->responseContains('id="workflow_moderation_state_report"');
  }

  /**
   * Test the behavior of the report when configurations are changed.
   */
  public function testReportWithConfigNotShowWorkflowModerationStateReport(): void {
    // Simulate changing the configuration for content insights.
    // This can be done by either setting configuration
    // via config factory, or by using UI.
    \Drupal::configFactory()->getEditable('content_insights_report.settings')
      ->set('show_workflow_moderation_state_report', 'no')
      ->save();

    // Log in as the user.
    $this->drupalLogin($this->reportViewer);

    // Visit the report page after configuration change.
    $url = Url::fromRoute('content_insights_report.report');
    $this->drupalGet($url);

    // Assert that the report is reflecting the configuration change.
    // Test div id and not name of report can be changed.
    $this->assertSession()->responseNotContains('<div id="workflow_moderation_state_report">');
  }

  /**
   * Test the behavior of the report when configurations are changed.
   */
  public function testReportWithConfigShowCreatedByAndDate(): void {

    // Simulate changing the configuration for content insights.
    // This can be done by either setting configuration
    // via config factory, or by using UI.
    \Drupal::configFactory()->getEditable('content_insights_report.settings')
      ->set('show_created_by_and_date', 'yes')
      ->save();

    // Log in as the user.
    $this->drupalLogin($this->reportViewer);

    // Visit the report page after configuration change.
    $url = Url::fromRoute('content_insights_report.report');
    $this->drupalGet($url);

    // Assert that the report is reflecting the configuration change.
    // Test div id and not name of report can be changed.
    $this->assertSession()->responseContains('<p id="created-by-and-date"');
  }

  /**
   * Test the behavior of the report when configurations are changed.
   */
  public function testReportWithConfigNotShowCreatedByAndDate(): void {

    // Simulate changing the configuration for content insights.
    // This can be done by either setting configuration
    // via config factory, or by using UI.
    \Drupal::configFactory()->getEditable('content_insights_report.settings')
      ->set('show_created_by_and_date', 'no')
      ->save();

    // Log in as the user.
    $this->drupalLogin($this->reportViewer);

    // Visit the report page after configuration change.
    $url = Url::fromRoute('content_insights_report.report');
    $this->drupalGet($url);

    // Assert that the report is reflecting the configuration change.
    // Test div id and not name of report can be changed.
    $this->assertSession()->responseNotContains('<p id="created-by-and-date"');
  }

  /**
   * Test the behavior of the report when configurations are changed.
   */
  public function testReportWithConfigPercentageTotal(): void {
    // Simulate changing the configuration for content insights.
    // This can be done by either setting configuration
    // via config factory, or by using UI.
    \Drupal::configFactory()->getEditable('content_insights_report.settings')
      ->set('show_insights_report', 'yes')
      ->set('percentage_total', 'all_nodes')
      ->save();

    // Log in as the user.
    $this->drupalLogin($this->reportViewer);

    // Visit the report page after configuration change.
    $url = Url::fromRoute('content_insights_report.report');
    $this->drupalGet($url);

    // Assert that the report is reflecting the configuration change.
    // Test div id and not name of report can be changed.
    $this->assertSession()->responseContains('<span class="asterisk">');
  }

  /**
   * Test the behavior of the report when configurations are changed.
   */
  public function testReportWithConfigNumberOfMonths(): void {

    // Simulate changing the configuration for content insights.
    // This can be done by either setting configuration
    // via config factory, or by using UI.
    \Drupal::configFactory()->getEditable('content_insights_report.settings')
      ->set('show_insights_report', 'yes')
      ->set('number_of_months', '6')
      ->save();

    // Log in as the user.
    $this->drupalLogin($this->reportViewer);

    // Visit the report page after configuration change.
    $url = Url::fromRoute('content_insights_report.report');
    $this->drupalGet($url);

    // Assert that the report is reflecting the configuration change.
    // Test div id and not name of report can be changed.
    $this->assertSession()->responseContains('<div id="insights-report-months">');
  }

  /**
   * Test the behavior of the report when configurations are changed.
   */
  public function testReportWithConfigShowPrint(): void {
    // Simulate changing the configuration for content insights.
    // This can be done by either setting configuration
    // via config factory, or by using UI.
    \Drupal::configFactory()->getEditable('content_insights_report.settings')
      ->set('show_print', 'yes')
      ->save();

    // Log in as the user.
    $this->drupalLogin($this->reportViewer);

    // Visit the report page after configuration change.
    $url = Url::fromRoute('content_insights_report.report');
    $this->drupalGet($url);

    // Use XPath to find the <img> tag and check its alt attribute.
    // XPath to find <img> with alt containing "Print".
    $img_elements = $this->xpath('//img[contains(@alt, "Print")]');

    // Assert that at least one <img> tag has alt="Print".
    $this->assertNotEmpty($img_elements, 'Image with alt="Print" found.');
  }

  /**
   * Test the behavior of the report when configurations are changed.
   */
  public function testReportWithConfigNotShowPrint(): void {
    // Simulate changing the configuration for content insights.
    // This can be done by either setting configuration
    // via config factory, or by using UI.
    \Drupal::configFactory()->getEditable('content_insights_report.settings')
      ->set('show_print', 'no')
      ->save();

    // Log in as the user.
    $this->drupalLogin($this->reportViewer);

    // Visit the report page after configuration change.
    $url = Url::fromRoute('content_insights_report.report');
    $this->drupalGet($url);

    // Use XPath to find the <img> tag and check its alt attribute.
    // XPath to find <img> with alt containing "Print".
    $img_elements = $this->xpath('//img[contains(@alt, "Print")]');

    // Assert that at least one <img> tag has alt="Print".
    $this->assertEmpty($img_elements, 'Image with alt="Print" found.');

  }

}

==> content_insights_report-1.0.9.tar.gz: content_insights_report/tests/src/Functional/ContentInsightsReportTest.php <==
<?php

declare(strict_types=1);

namespace Drupal\Tests\content_insights_report\Functional;

use Drupal\Core\Url;
use Drupal\node\Entity\Node;
use Drupal\node\Entity\NodeType;
use Drupal\Tests\BrowserTestBase;
use Drupal\Tests\content_moderation\Traits\ContentModerationTestTrait;
use Drupal\workflows\Entity\Workflow;

/**
 * Tests the Content Insights report generation functionality.
 *
 * @group content_insights_report
 */
class ContentInsightsReportTest extends BrowserTestBase {

  use ContentModerationTestTrait;

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'node',
    'content_insights_report',
    'content_moderation',
    'workflows',
    'system',
    'user',
  ];

  /**
   * {@inheritdoc}
   */
  protected $profile = 'minimal';

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * A user with admin permissions.
   *
   * @var \Drupal\user\UserInterface[]
   */
  protected $reportViewer;

  /**
   * {@inheritdoc}
   */
  public function setUp(): void {
    parent::setUp();

    // Create a user with permission to access the report.
    $this->reportViewer = $this->drupalCreateUser([
      'administer content_insights_report settings',
      'view content_insights_report report',
      'administer nodes',
    ]);

    // Enable Content Moderation & Workflow module if not already enabled.
    $this->container
      ->get('module_installer')
      ->install([
        'node',
        'workflows',
        'content_moderation',
        'content_insights_report',
      ]);

    // Create a content type (if not already created).
    \Drupal::entityTypeManager()
      ->getStorage('node_type')
      ->load('article') ?: NodeType::create([
        'type' => 'article',
        'name' => 'Article',
      ])->save();

    // Create and assign a content moderation workflow.
    $workflow = Workflow::create([
      'id' => 'editorial',
      'label' => 'Editorial workflow',
      'type' => 'content_moderation',
    ]);
    $workflow->getTypePlugin()->addEntityTypeAndBundle('node', 'article');
    $workflow->save();

    // Create a node with "Draft" moderation state.
    $node = Node::create([
      'type' => 'article',
      'title' => 'Test Article',
      'body' => 'Test body content.',
    ]);
    // Set the moderation state to draft.
    $node->set('moderation_state', 'draft');
    $node->save();
  }

  /**
   * Test the Content Insights report page.
   */
  public function testReportPage(): void {
    // Log in as the test user.
    $this->drupalLogin($this->reportViewer);

    // Check the URL for the report page.
    $url = Url::fromRoute('content_insights_report.report');
    $this->drupalGet($url);

    $status = $this->getSession()->getStatusCode();
    if ($status !== 200) {
      $page = $this->getSession()->getPage();
      $this->assertSame("status=$status", $page->getContent());
      $this->fail('Failed to navigate to ' . $url);
    }

    // Assert that the report page loads.
    $this->assertSession()->statusCodeEquals(200);

    // Assert specific content is displayed on the page.
    // Test div id and not name of report can be changed.
    $this->assertSession()->responseContains('<div id="content_insights">');
  }

  /**
   * Test the behavior of the report when configurations are changed.
   */
  public function testReportWithConfigShowSummary(): void {
    // Simulate changing the configuration for content insights.
    // This can be done by either setting configuration
    // via config factory, or by using UI.
    \Drupal::configFactory()->getEditable('content_insights_report.settings')
      ->set('show_summary', TRUE)
      ->save();

    // Log in as the user.
    $this->drupalLogin($this->reportViewer);

    // Visit the report page after configuration change.
    $url = Url::fromRoute('content_insights_report.report');
    $this->drupalGet($url);

    // Assert that the report is reflecting the configuration change.
    // Test div id and not name of report can be changed.
    $this->assertSession()->responseContains('<div id="content_summary_report">');
  }

  /**
   * Test the behavior of the report when configurations are changed.
   */
  public function testReportWithConfigNotShowSummary(): void {

    // Simulate changing the configuration for content insights.
    // This can be done by either setting configuration
    // via config factory, or by using UI.
    \Drupal::configFactory()->getEditable('content_insights_report.settings')
      ->set('show_summary', FALSE)
      ->save();

    // Log in as the user.
    $this->drupalLogin($this->reportViewer);

    // Visit the report page after configuration change.
    $url = Url::fromRoute('content_insights_report.report');
    $this->drupalGet($url);

    // Assert that the report is reflecting the configuration change.
    // Test div id and not name of report can be changed.
    $this->assertSession()->responseNotContains('<div id="content_summary_report">');
  }

  /**
   * Test the behavior of the report when configurations are changed.
   */
  public function testReportWithConfigShowContentInsightsReport(): void {

    // Simulate changing the configuration for content insights.
    // This can be done by either setting configuration
    // via config factory, or by using UI.
    \Drupal::configFactory()->getEditable('content_insights_report.settings')
      ->set('show_insights_report', TRUE)
      ->save();

    // Log in as the user.
    $this->drupalLogin($this->reportViewer);

    // Visit the report page after configuration change.
    $url = Url::fromRoute('content_insights_report.report');
    $this->drupalGet($url);

    // Assert that the report is reflecting the configuration change.
    // Test div id and not name of report can be changed.
    $this->assertSession()->responseContains('<div id="content_insights_report">');
  }

  /**
   * Test the behavior of the report when configurations are changed.
   */
  public function testReportWithConfigNotShowContentInsightsReport(): void {

    // Simulate changing the configuration for content insights.
    // This can be done by either setting configuration
    // via config factory, or by using UI.
    \Drupal::configFactory()->getEditable('content_insights_report.settings')
      ->set('show_insights_report', FALSE)
      ->save();

    // Log in as the user.
    $this->drupalLogin($this->reportViewer);

    // Visit the report page after configuration change.
    $url = Url::fromRoute('content_insights_report.report');
    $this->drupalGet($url);

    // Assert that the report is reflecting the configuration change.
    // Test div id and not name of report can be changed.
    $this->assertSession()->responseNotContains('<div id="content_insights_report">');
  }

  /**
   * Test the behavior of the report when configurations are changed.
   */
  public function testReportWithConfigShowWorkflowModerationStateReport(): void {

    // Simulate changing the configuration for content insights.
    // This can be done by either setting configuration
    // via config factory, or by using UI.
    \Drupal::configFactory()->getEditable('content_insights_report.settings')
      ->set('show_workflow_moderation_state_report', TRUE)
      ->set('show_empty_results', TRUE)
      ->save();

    // Log in as the user.
    $this->drupalLogin($this->reportViewer);

    // Visit the report page after configuration change.
    $url = Url::fromRoute('content_insights_report.report');
    $this->drupalGet($url);

    // Assert that the report is reflecting the configuration change.
    // Test div id and not name of report can be changed.
    $this->assertSession()->responseContains('id="workflow_moderation_state_report"');
  }

  /**
   * Test the behavior of the report when configurations are changed.
   */
  public function testReportWithConfigNotShowWorkflowModerationStateReport(): void {
    // Simulate changing the configuration for content insights.
    // This can be done by either setting configuration
    // via config factory, or by using UI.
    \Drupal::configFactory()->getEditable('content_insights_report.settings')
      ->set('show_workflow_moderation_state_report', FALSE)
      ->save();

    // Log in as the user.
    $this->drupalLogin($this->reportViewer);

    // Visit the report page after configuration change.
    $url = Url::fromRoute('content_insights_report.report');
    $this->drupalGet($url);

    // Assert that the report is reflecting the configuration change.
    // Test div id and not name of report can be changed.
    $this->assertSession()->responseNotContains('<div id="workflow_moderation_state_report">');
  }

  /**
   * Test the behavior of the report when configurations are changed.
   */
  public function testReportWithConfigShowCreatedByAndDate(): void {

    // Simulate changing the configuration for content insights.
    // This can be done by either setting configuration
    // via config factory, or by using UI.
    \Drupal::configFactory()->getEditable('content_insights_report.settings')
      ->set('show_created_by_and_date', TRUE)
      ->save();

    // Log in as the user.
    $this->drupalLogin($this->reportViewer);

    // Visit the report page after configuration change.
    $url = Url::fromRoute('content_insights_report.report');
    $this->drupalGet($url);

    // Assert that the report is reflecting the configuration change.
    // Test div id and not name of report can be changed.
    $this->assertSession()->responseContains('<p id="created-by-and-date"');
  }

  /**
   * Test the behavior of the report when configurations are changed.
   */
  public function testReportWithConfigNotShowCreatedByAndDate(): void {

    // Simulate changing the configuration for content insights.
    // This can be done by either setting configuration
    // via config factory, or by using UI.
    \Drupal::configFactory()->getEditable('content_insights_report.settings')
      ->set('show_created_by_and_date', FALSE)
      ->save();

    // Log in as the user.
    $this->drupalLogin($this->reportViewer);

    // Visit the report page after configuration change.
    $url = Url::fromRoute('content_insights_report.report');
    $this->drupalGet($url);

    // Assert that the report is reflecting the configuration change.
    // Test div id and not name of report can be changed.
    $this->assertSession()->responseNotContains('<p id="created-by-and-date"');
  }

  /**
   * Test the behavior of the report when configurations are changed.
   */
  public function testReportWithConfigPercentageTotal(): void {
    // Simulate changing the configuration for content insights.
    // This can be done by either setting configuration
    // via config factory, or by using UI.
    \Drupal::configFactory()->getEditable('content_insights_report.settings')
      ->set('show_insights_report', TRUE)
      ->set('percentage_total', 'all_nodes')
      ->save();

    // Log in as the user.
    $this->drupalLogin($this->reportViewer);

    // Visit the report page after configuration change.
    $url = Url::fromRoute('content_insights_report.report');
    $this->drupalGet($url);

    // Assert that the report is reflecting the configuration change.
    // Test div id and not name of report can be changed.
    $this->assertSession()->responseContains('info-icon');
  }

  /**
   * Test the behavior of the report when configurations are changed.
   */
  public function testReportWithConfigNumberOfMonths(): void {

    // Simulate changing the configuration for content insights.
    // This can be done by either setting configuration
    // via config factory, or by using UI.
    \Drupal::configFactory()->getEditable('content_insights_report.settings')
      ->set('show_insights_report', TRUE)
      ->set('number_of_months', '6')
      ->save();

    // Log in as the user.
    $this->drupalLogin($this->reportViewer);

    // Visit the report page after configuration change.
    $url = Url::fromRoute('content_insights_report.report');
    $this->drupalGet($url);

    // Assert that the report is reflecting the configuration change.
    // Test div id and not name of report can be changed.
    $this->assertSession()->responseContains('<div id="insights-report-months">');
  }

  /**
   * Test the behavior of the report when configurations are changed.
   */
  public function testReportWithConfigShowPrint(): void {
    // Simulate changing the configuration for content insights.
    // This can be done by either setting configuration
    // via config factory, or by using UI.
    \Drupal::configFactory()->getEditable('content_insights_report.settings')
      ->set('show_print', TRUE)
      ->save();

    // Log in as the user.
    $this->drupalLogin($this->reportViewer);

    // Visit the report page after configuration change.
    $url = Url::fromRoute('content_insights_report.report');
    $this->drupalGet($url);

    // Use XPath to find the <img> tag and check its alt attribute.
    // XPath to find <img> with alt containing "Print".
    $img_elements = $this->xpath('//img[contains(@alt, "Print")]');

    // Assert that at least one <img> tag has alt="Print".
    $this->assertNotEmpty($img_elements, 'Image with alt="Print" found.');
  }

  /**
   * Test the behavior of the report when configurations are changed.
   */
  public function testReportWithConfigNotShowPrint(): void {
    // Simulate changing the configuration for content insights.
    // This can be done by either setting configuration
    // via config factory, or by using UI.
    \Drupal::configFactory()->getEditable('content_insights_report.settings')
      ->set('show_print', FALSE)
      ->save();

    // Log in as the user.
    $this->drupalLogin($this->reportViewer);

    // Visit the report page after configuration change.
    $url = Url::fromRoute('content_insights_report.report');
    $this->drupalGet($url);

    // Use XPath to find the <img> tag and check its alt attribute.
    // XPath to find <img> with alt containing "Print".
    $img_elements = $this->xpath('//img[contains(@alt, "Print")]');

    // Assert that at least one <img> tag has alt="Print".
    $this->assertEmpty($img_elements, 'Image with alt="Print" found.');

  }

}
